@@ -55,6 +55,8 @@ public class ChronopicWindow
 	[Widget] Gtk.Label label_connect_contacts;
 	[Widget] Gtk.Label label_connect_encoder;
 
+	[Widget] Gtk.Frame frame_supplementary;
+
 	[Widget] Gtk.Image image_cp1_yes;
 	[Widget] Gtk.Image image_cp1_no;
 	[Widget] Gtk.Image image_cp2_yes;
@@ -83,7 +85,7 @@ public class ChronopicWindow
 	[Widget] Gtk.Button button_connect_cp3;
 	[Widget] Gtk.Button button_connect_cp4;
 	
-	[Widget] Gtk.CheckButton checkbutton_multi_show;
+	[Widget] Gtk.CheckButton check_multichronopic_show;
 	[Widget] Gtk.Table table_multi_chronopic;
 	//[Widget] Gtk.Button button_reload;
 	
@@ -96,6 +98,14 @@ public class ChronopicWindow
 	[Widget] Gtk.Image chronopic_image;
 	[Widget] Gtk.TextView textview_ports_found_explanation;
 
+	//Automatic firmware stuff
+	[Widget] Gtk.CheckButton check_multitest_show;
+	[Widget] Gtk.Table table_chronopic_auto;
+	[Widget] Gtk.SpinButton spin_auto_change_debounce;
+	[Widget] Gtk.Label label_auto_check;
+	[Widget] Gtk.Label label_auto_check_debounce;
+	[Widget] Gtk.Label label_auto_change_debounce;
+
 	//chronopic connection thread
 	Thread thread;
 	bool needUpdateChronopicWin;
@@ -119,7 +129,6 @@ public class ChronopicWindow
 		OFF
 	}
 	bool connected;
-	string type;	//"contacts" or "encoder"
 	bool volumeOn;
 	int currentCp; //1 to 4
 	bool cancelledByUser;
@@ -146,6 +155,8 @@ public class ChronopicWindow
 
 	States loggedState;		//log of last state
 	
+	public enum ChronojumpMode { JUMPORRUN, ENCODER, OTHER };
+	
 
 	public ChronopicWindow(ArrayList myCpd)
 	{
@@ -185,7 +196,7 @@ public class ChronopicWindow
 	}
 	
 	//recreate is used when a Chronopic was disconnected
-	//port names com from gui/chronojump.cs to this method (myCpd)
+	//port names come from gui/chronojump.cs to this method (myCpd)
 	static public ChronopicWindow Create (ArrayList myCpd, string myEncoderPort, bool recreate, bool volumeOn)
 	{
 		if (ChronopicWindowBox != null && recreate) {
@@ -207,21 +218,24 @@ public class ChronopicWindow
 		return ChronopicWindowBox;
 	}
 
-	static public ChronopicWindow View (string type, bool volumeOn)
+	static public ChronopicWindow View (ChronojumpMode cmode, bool volumeOn)
 	{
 		if (ChronopicWindowBox == null) {
 			ChronopicWindowBox = new ChronopicWindow (cpd);
 		} 
 		
-		ChronopicWindowBox.type = type;
+		ChronopicWindowBox.volumeOn = volumeOn;
 		
-		if(type == "contacts")
+		if(cmode == ChronojumpMode.JUMPORRUN || cmode == ChronojumpMode.OTHER) {
 			ChronopicWindowBox.notebook_main.CurrentPage = 0;
-		else
+			ChronopicWindowBox.checkChronopicDisconnected(); //encoder does not need this because there's no connection
+		
+			ChronopicWindowBox.frame_supplementary.Visible = 
+				(cmode == ChronojumpMode.OTHER); //can have multichronopic
+		}
+		else	//cmode == ChronojumpMode.ENCODER)
 			ChronopicWindowBox.notebook_main.CurrentPage = 1;
 		
-		ChronopicWindowBox.volumeOn = volumeOn;
-		ChronopicWindowBox.checkChronopicDisconnected();
 		ChronopicWindowBox.createCombos();
 
 		//ports info comes from gui/chronojump.cs to Create mehod
@@ -242,8 +256,11 @@ Log.WriteLine("bbb");
 		label_connect_encoder.UseMarkup = true;
 		
 		
-		checkbutton_multi_show.Active = false;
+		check_multichronopic_show.Active = false;
 		table_multi_chronopic.Visible = false;
+		
+		check_multitest_show.Active = false;
+		check_multitest_show.Sensitive = false;
 
 		if(isWindows) {
 			combo_linux1.Hide();
@@ -283,7 +300,10 @@ Log.WriteLine("bbb");
 	}
 	
 	//check if user has disconnected chronopic or port has changed
-	private void checkChronopicDisconnected() {
+	private void checkChronopicDisconnected() 
+	{
+		bool errorFound = false;
+	
 		foreach(ChronopicPortData a in cpd) {
 			Chronopic myCP;
 			Chronopic.Plataforma myPS;
@@ -296,38 +316,51 @@ Log.WriteLine("bbb");
 			} else if(a.Num == 3) {
 				myCP = cp3;
 				myPS = platformState3;
-			} else { //if(a.Num == 4) {
+			} else {
 				myCP = cp4;
 				myPS = platformState4;
 			}
 			
-			int errorCount = 0;
 			bool ok = false;	
 			if(a.Connected) {
-				//try {
+				string myPort = a.Port;
+
+				//http://www.raspberrypi.org/forums/viewtopic.php?f=66&t=88415
+				//https://bugzilla.xamarin.com/show_bug.cgi?id=15514
+				if(! isWindows) {
+					if(! File.Exists(myPort)) {
+						Log.WriteLine("port does not exists: " + myPort);
+						errorFound = true;
+					}
+				}
+			
+				if(! errorFound) {
+					//try {
 					ok = myCP.Read_platform(out myPS);
-				//} catch { 
-				//	Log.WriteLine("catch at 1"); 
-				//}
-				if(!ok) {
-					Log.WriteLine("false at 1");
-					errorCount ++;
+					//} catch { 
+					//	Log.WriteLine("catch at 1"); 
+					//}
+					if(!ok) {
+						Log.WriteLine("false at 1");
+						errorFound = true;
+					}
 				}
 			}
-			if(errorCount > 0) {
-				ArrayList myCPD = new ArrayList();
-				for(int i=1; i<=4;i++) {
-					ChronopicPortData b = new ChronopicPortData(i,"",false);
-					myCPD.Add(b);
-				}
-				Create (myCPD, encoderPort, true, volumeOn);
-				
-				connected = false;
-				
-				new DialogMessage(Constants.MessageTypes.WARNING, 
-						Catalog.GetString("One or more Chronopics have been disconnected.") + "\n" + 
-						Catalog.GetString("Please connect again, and configure on Chronopic window."));
+		}
+			
+		if(errorFound) {
+			ArrayList myCPD = new ArrayList();
+			for(int i=1; i<=4; i++) {
+				ChronopicPortData b = new ChronopicPortData(i,"",false);
+				myCPD.Add(b);
 			}
+			Create (myCPD, encoderPort, true, volumeOn);
+
+			connected = false;
+
+			new DialogMessage(Constants.MessageTypes.WARNING, 
+					Catalog.GetString("One or more Chronopics have been disconnected.") + "\n" + 
+					Catalog.GetString("Please connect again, and configure on Chronopic window."));
 		}
 	}
 	
@@ -545,12 +578,14 @@ Log.WriteLine("bbb");
 		label_title.Text = message;
 		label_title.UseMarkup = true;
 		button_cancel.Sensitive = false;
+		check_multitest_show.Sensitive = true;
 	}
 
 	private void sensitivityDisconnected(string message) {
 		Log.WriteLine("DISCONNECTED!!");
 		label_title.Text = message;
 		button_cancel.Sensitive = false;
+		check_multitest_show.Sensitive = false;
 	}
 		
 	private void on_button_help_ports_clicked (object o, EventArgs args) {
@@ -631,8 +666,8 @@ Log.WriteLine("bbb");
 		}
 	}
 	
-	private void on_checkbutton_multi_show_clicked(object o, EventArgs args) {
-		table_multi_chronopic.Visible = checkbutton_multi_show.Active;
+	private void on_check_multichronopic_show_clicked(object o, EventArgs args) {
+		table_multi_chronopic.Visible = check_multichronopic_show.Active;
 	}
 
 	private void on_button_connect_cp_clicked (object o, EventArgs args) {
@@ -683,7 +718,52 @@ Log.WriteLine("bbb");
 	}
 
 
+	// Chronopic Automatic Firmware ---------------
+	
+	private void on_check_multitest_show_clicked (object o, EventArgs args) 
+	{
+		table_chronopic_auto.Visible = check_multitest_show.Active;
+	}
+
+	private void on_button_auto_check_auto_clicked (object o, EventArgs args)
+	{
+		ChronopicAuto ca = new ChronopicAutoCheck();
+		label_auto_check.Text = ca.Read(sp);
+	}	
+
+	private void on_button_auto_check_debounce_clicked (object o, EventArgs args)
+	{
+		ChronopicAuto ca = new ChronopicAutoCheckDebounce();
+		label_auto_check_debounce.Text = ca.Read(sp);
+	}	
+
+	private void on_button_auto_change_debounce_clicked (object o, EventArgs args)
+	{
+		ChronopicAuto ca = new ChronopicAutoChangeDebounce();
+		ca.Write(sp, (int) spin_auto_change_debounce.Value);
+		
+		ca = new ChronopicAutoCheckDebounce();
+		label_auto_change_debounce.Text = ca.Read(sp);
+	}	
+	
+	private void on_button_auto_check_help_clicked (object o, EventArgs args) 
+	{
+		new DialogMessage(Constants.MessageTypes.INFO, 
+				"50 ms recommended for jumps." + "\n" + 
+				"10 ms recommended for runs.");
+	}
+
+	private void on_button_auto_change_help_clicked (object o, EventArgs args) 
+	{
+		new DialogMessage(Constants.MessageTypes.INFO, 
+				"Minimum value will be 50 ms again when user unplugs USB cable.");
+	}
+
+	// end of Chronopic Automatic Firmware ---------------
+
+
 	void prepareChronopicConnection() {
+		check_multitest_show.Sensitive = false;
 		frame_connection.Visible = true;
 		
 		label_title.Text = Catalog.GetString("Please touch the platform or click Chronopic <i>TEST</i> button");
@@ -910,6 +990,10 @@ Log.WriteLine("bbb");
 		return count;
 	}
 
+	public string GetContactsFirstPort() {
+		return ((ChronopicPortData) cpd[0]).Port;
+	}
+
 	public string GetEncoderPort() {
 		if(isWindows)
 			return UtilGtk.ComboGetActive(combo_windows_encoder);
@@ -933,6 +1017,15 @@ Log.WriteLine("bbb");
 	public Chronopic CP4 {
 		get { return cp4; }
 	}
+	
+	public SerialPort SP {
+		get { return sp; }
+	}
+	
+	public Chronopic.Plataforma PlatformState {	//on (in platform), off (jumping), or unknow
+		get { return platformState; }
+	}
+
 
 	//connected to a Chronopic	
 	public bool Connected {
