@@ -38,8 +38,6 @@ public class EditJumpWindow : EditEventWindow
 	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_mode_vertical;
 	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_mode_horizontal;
 	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_mode_lateral;
-	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_right;
-	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_left;
 	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_dominance_this_limb;
 	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_dominance_opposite;
 	[Widget] private Gtk.RadioButton jumps_radiobutton_single_leg_dominance_unknown;
@@ -90,7 +88,7 @@ public class EditJumpWindow : EditEventWindow
 
 		EditJumpWindowBox.fillDialog (myEvent);
 		
-		if(myEvent.Type == "slCMJ")
+		if(myEvent.Type == "slCMJleft" || myEvent.Type == "slCMJright")
 			EditJumpWindowBox.fillSingleLeg (myEvent.Description);
 		
 		EditJumpWindowBox.edit_event.Show ();
@@ -125,9 +123,9 @@ public class EditJumpWindow : EditEventWindow
 		Jump myJump = (Jump) myEvent;
 		string [] myTypes;
 		if (myJump.TypeHasFall) {
-			myTypes = SqliteJumpType.SelectJumpTypes("", "TC", true); //don't show allJumpsName row, TC jumps, only select name
+			myTypes = SqliteJumpType.SelectJumpTypes(false, "", "TC", true); //don't show allJumpsName row, TC jumps, only select name
 		} else {
-			myTypes = SqliteJumpType.SelectJumpTypes("", "nonTC", true); //don't show allJumpsName row, nonTC jumps, only select name
+			myTypes = SqliteJumpType.SelectJumpTypes(false, "", "nonTC", true); //don't show allJumpsName row, nonTC jumps, only select name
 		}
 		return myTypes;
 	}
@@ -201,23 +199,21 @@ public class EditJumpWindow : EditEventWindow
 
 	private bool slCMJDescriptionIsValid(string description) {
 		string [] d = description.Split(new char[] {' '});
-		if(d.Length != 6)
+		if(d.Length != 5)
 			return false;
 		if(! Util.IsNumber(d[4], false))
 			return false;
 		if(d[0] != "Vertical" && d[0] != "Horizontal" && d[0] != "Lateral")
 			return false;
-		if(d[1] != "Right" && d[1] != "Left")
+		if(d[1] != "This" && d[1] != "Opposite" && d[1] != "Unknown")
 			return false;
-		if(d[2] != "This" && d[2] != "Opposite" && d[2] != "Unknown")
-			return false;
-		if(d[3] != "This" && d[3] != "Opposite" && d[3] != "Both")
+		if(d[2] != "This" && d[2] != "Opposite" && d[2] != "Both")
 			return false;
 
 		return true;
 	}
 	private string slCMJDescriptionDefault() {
-		string descDefault = "Vertical Right This This 0 90";
+		string descDefault = "Vertical Unknown Both 0 90";
 		entry_description.Text = descDefault;
 		return descDefault;
 	}
@@ -243,26 +239,22 @@ public class EditJumpWindow : EditEventWindow
 			case "Horizontal":
 				jumps_radiobutton_single_leg_mode_horizontal.Active = true;
 				jumps_spinbutton_single_leg_distance.Sensitive = true;
-				jumps_spinbutton_single_leg_distance.Value = Convert.ToInt32(d[4]);
-				jumps_spinbutton_single_leg_jump_angle.Value = Convert.ToInt32(d[5]);
+				jumps_spinbutton_single_leg_distance.Value = Convert.ToInt32(d[3]);
+				jumps_spinbutton_single_leg_jump_angle.Value = Convert.ToInt32(d[4]);
 				break;
 			case "Lateral":
 				jumps_radiobutton_single_leg_mode_lateral.Active = true;
 				jumps_spinbutton_single_leg_distance.Sensitive = true;
-				jumps_spinbutton_single_leg_distance.Value = Convert.ToInt32(d[4]);
-				jumps_spinbutton_single_leg_jump_angle.Value = Convert.ToInt32(d[5]);
+				jumps_spinbutton_single_leg_distance.Value = Convert.ToInt32(d[3]);
+				jumps_spinbutton_single_leg_jump_angle.Value = Convert.ToInt32(d[4]);
 				break;
 		}
 		switch(d[1]) {
-			case "Right": jumps_radiobutton_single_leg_right.Active = true; break;
-			case "Left": jumps_radiobutton_single_leg_left.Active = true; break;
-		}
-		switch(d[2]) {
 			case "This": jumps_radiobutton_single_leg_dominance_this_limb.Active = true; break;
 			case "Opposite": jumps_radiobutton_single_leg_dominance_opposite.Active = true; break;
 			case "Unknown": jumps_radiobutton_single_leg_dominance_unknown.Active = true; break;
 		}
-		switch(d[3]) {
+		switch(d[2]) {
 			case "This": jumps_radiobutton_single_leg_fall_this_limb.Active = true; break;
 			case "Opposite": jumps_radiobutton_single_leg_fall_opposite.Active = true; break;
 			case "Both": jumps_radiobutton_single_leg_fall_both.Active = true; break;
@@ -280,7 +272,8 @@ public class EditJumpWindow : EditEventWindow
 
 			if(jumps_radiobutton_single_leg_mode_vertical.Active) {
 				d[0] = "Vertical";	
-				d[4] = "0";	
+				d[3] = "0";	//distance
+				d[4] = "90";
 			}
 			else if(jumps_radiobutton_single_leg_mode_horizontal.Active)
 				d[0] = "Horizontal";
@@ -288,7 +281,7 @@ public class EditJumpWindow : EditEventWindow
 				d[0] = "Lateral";
 			
 			entry_description.Text = 
-				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4] + " " + d[5];
+				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4];
 			fillSingleLeg(entry_description.Text);
 		}
 	}
@@ -300,13 +293,15 @@ public class EditJumpWindow : EditEventWindow
 				description = slCMJDescriptionDefault();
 			string [] d = description.Split(new char[] {' '});
 
-			if(jumps_radiobutton_single_leg_right.Active)
-				d[1] = "Right";	
+			if(jumps_radiobutton_single_leg_dominance_this_limb.Active)
+				d[1] = "This";	
+			else if(jumps_radiobutton_single_leg_dominance_opposite.Active)
+				d[1] = "Opposite";
 			else
-				d[1] = "Left";
+				d[1] = "Unknown"; //default since 1.4.8
 
 			entry_description.Text = 
-				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4] + " " + d[5];
+				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4];
 			fillSingleLeg(entry_description.Text);
 		}
 	}
@@ -318,35 +313,15 @@ public class EditJumpWindow : EditEventWindow
 				description = slCMJDescriptionDefault();
 			string [] d = description.Split(new char[] {' '});
 
-			if(jumps_radiobutton_single_leg_dominance_this_limb.Active)
+			if(jumps_radiobutton_single_leg_fall_this_limb.Active)
 				d[2] = "This";	
-			else if(jumps_radiobutton_single_leg_dominance_opposite.Active)
+			else if(jumps_radiobutton_single_leg_fall_opposite.Active)
 				d[2] = "Opposite";
 			else
-				d[2] = "Unknown";
+				d[2] = "Both"; //default since 1.4.8
 
 			entry_description.Text = 
-				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4] + " " + d[5];
-			fillSingleLeg(entry_description.Text);
-		}
-	}
-
-	protected override void on_radio_single_leg_4_toggled(object o, EventArgs args) {
-		if(toggleRaisesSignal) {
-			string description = entry_description.Text;
-			if(! slCMJDescriptionIsValid(description))
-				description = slCMJDescriptionDefault();
-			string [] d = description.Split(new char[] {' '});
-
-			if(jumps_radiobutton_single_leg_fall_this_limb.Active)
-				d[3] = "This";	
-			else if(jumps_radiobutton_single_leg_fall_opposite.Active)
-				d[3] = "Opposite";
-			else
-				d[3] = "Both";
-
-			entry_description.Text = 
-				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4] + " " + d[5];
+				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4];
 			fillSingleLeg(entry_description.Text);
 		}
 	}
@@ -359,14 +334,14 @@ public class EditJumpWindow : EditEventWindow
 			string [] d = description.Split(new char[] {' '});
 
 			int distance = Convert.ToInt32(jumps_spinbutton_single_leg_distance.Value);
-			d[4] = distance.ToString();
+			d[3] = distance.ToString();
 			
-			d[5] = Util.CalculateJumpAngle(
+			d[4] = Util.CalculateJumpAngle(
 					Convert.ToDouble(Util.GetHeightInCentimeters(entryTv)), 
 					distance ).ToString();
 
 			entry_description.Text = 
-				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4] + " " + d[5];
+				d[0] + " " + d[1] + " " + d[2] + " " + d[3] + " " + d[4];
 			fillSingleLeg(entry_description.Text);
 		}
 	}
@@ -405,9 +380,9 @@ public class EditJumpWindow : EditEventWindow
 			entry_weight_value.Sensitive = false;
 		}
 		
-		frame_jumps_single_leg.Visible = myJumpType.Name == "slCMJ";
-		entry_description.Sensitive = myJumpType.Name != "slCMJ";
-		if(myJumpType.Name == "slCMJ") {
+		frame_jumps_single_leg.Visible = (myJumpType.Name == "slCMJleft" || myJumpType.Name == "slCMJright");
+		entry_description.Sensitive = (myJumpType.Name != "slCMJleft" && myJumpType.Name != "slCMJright");
+		if(myJumpType.Name == "slCMJleft" || myJumpType.Name == "slCMJright") {
 			fillSingleLeg(entry_description.Text);
 		}
 	}
@@ -998,11 +973,15 @@ partial class ChronoJumpWindow
 {
 	//options jumps
 	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_weight;
+	[Widget] Gtk.Box extra_window_jumps_vbox_fall;
+	[Widget] Gtk.RadioButton extra_window_jumps_radio_dj_fall_predefined;
+	[Widget] Gtk.RadioButton extra_window_jumps_radio_dj_fall_calculate;
+	[Widget] Gtk.Label extra_window_jumps_label_dj_start_inside;
+	[Widget] Gtk.Label extra_window_jumps_label_dj_start_outside;
 	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_fall;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_kg;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_weight;
 	[Widget] Gtk.Label extra_window_jumps_label_weight;
-	[Widget] Gtk.Label extra_window_jumps_label_fall;
 	[Widget] Gtk.Label extra_window_jumps_label_cm;
 	[Widget] Gtk.Label extra_window_jumps_label_dj_arms;
 	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_arms;
@@ -1015,8 +994,6 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_vertical;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_horizontal;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_lateral;
-	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_right;
-	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_left;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_dominance_this_limb;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_dominance_opposite;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_dominance_unknown;
@@ -1046,7 +1023,7 @@ partial class ChronoJumpWindow
 	//static double distance;
 
 	//jumps
-	string extra_window_jumps_option = "Kg";
+	string extra_window_jumps_option = "%";
 	//double extra_window_jumps_weight = 20;
 	double extra_window_jumps_fall = 20;
 	bool extra_window_jumps_arms = false;
@@ -1078,7 +1055,16 @@ partial class ChronoJumpWindow
 		}
 		return t;
 	}
-	
+
+
+	private void on_extra_window_jumps_radio_dj_fall_calculate_toggled (object o, EventArgs args) {
+		extra_window_jumps_label_dj_start_inside.Visible = true;
+		extra_window_jumps_label_dj_start_outside.Visible = false;
+	}
+	private void on_extra_window_jumps_radio_dj_fall_predefined_toggled (object o, EventArgs args) {
+		extra_window_jumps_label_dj_start_inside.Visible = false;
+		extra_window_jumps_label_dj_start_outside.Visible = true;
+	}
 	
 	private void on_extra_window_jumps_test_changed(object o, EventArgs args)
 	{
@@ -1154,7 +1140,7 @@ partial class ChronoJumpWindow
 		} else 
 			extra_window_showTechniqueArmsData(false, false); //visible, sensitive
 		
-		extra_window_jumps_spinbutton_weight.Value = 20;
+		extra_window_jumps_spinbutton_weight.Value = 100;
 		extra_window_jumps_spinbutton_fall.Value = extra_window_jumps_fall;
 		if (extra_window_jumps_option == "Kg") {
 			extra_window_jumps_radiobutton_kg.Active = true;
@@ -1162,8 +1148,8 @@ partial class ChronoJumpWindow
 			extra_window_jumps_radiobutton_weight.Active = true;
 		}
 
-		extra_window_showSingleLegStuff(myJumpType.Name == "slCMJ");
-		if(myJumpType.Name == "slCMJ") {
+		extra_window_showSingleLegStuff(myJumpType.Name == "slCMJleft" || myJumpType.Name == "slCMJright");
+		if(myJumpType.Name == "slCMJleft" || myJumpType.Name == "slCMJright") {
 			hasOptions = true;
 			frame_extra_window_jumps_single_leg_input.Sensitive = false;
 			extra_window_jumps_spin_single_leg_distance.Value = 0;
@@ -1323,11 +1309,11 @@ partial class ChronoJumpWindow
 			extra_window_jumps_rj_label_fall.Visible = show;
 			extra_window_jumps_rj_spinbutton_fall.Visible = show;
 			extra_window_jumps_rj_label_cm.Visible = show;
-		} else {
-			extra_window_jumps_label_fall.Visible = show;
-			extra_window_jumps_spinbutton_fall.Visible = show;
-			extra_window_jumps_label_cm.Visible = show;
-		}
+		
+			//only on simple jumps	
+			extra_window_jumps_vbox_fall.Visible = false;
+		} else 
+			extra_window_jumps_vbox_fall.Visible = show;
 	}
 	
 	private void extra_window_showLimitData (bool show) {
@@ -1386,16 +1372,13 @@ partial class ChronoJumpWindow
 		else if(extra_window_jumps_radiobutton_single_leg_mode_horizontal.Active) str = "Horizontal";
 		else str = "Lateral";
 		
-		if(extra_window_jumps_radiobutton_single_leg_right.Active) str += " Right";
-		else str += " Left";
-		
 		if(extra_window_jumps_radiobutton_single_leg_dominance_this_limb.Active) str += " This";
 		else if(extra_window_jumps_radiobutton_single_leg_dominance_opposite.Active) str += " Opposite";
-		else str += " Unknown";
+		else str += " Unknown"; //default since 1.4.8
 
 		if(extra_window_jumps_radiobutton_single_leg_fall_this_limb.Active) str += " This";
 		else if(extra_window_jumps_radiobutton_single_leg_fall_opposite.Active) str += " Opposite";
-		else str += " Both";
+		else str += " Both"; //default since 1.4.8
 
 		return str;
 	}
@@ -1483,7 +1466,7 @@ public class JumpsMoreWindow : EventMoreWindow
 	protected override void fillTreeView (Gtk.TreeView tv, TreeStore store) 
 	{
 		//select data without inserting an "all jumps", without filter, and not obtain only name of jump
-		string [] myJumpTypes = SqliteJumpType.SelectJumpTypes("", "", false);
+		string [] myJumpTypes = SqliteJumpType.SelectJumpTypes(false, "", "", false);
 
 		//remove typesTranslated
 		typesTranslated = new String [myJumpTypes.Length];
