@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -85,7 +85,7 @@ public class RunTypeAddWindow
 
 	RunTypeAddWindow (Gtk.Window parent, bool simple) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "run_type_add", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "run_type_add", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		
@@ -166,7 +166,7 @@ public class RunTypeAddWindow
 		//Console.WriteLine(getEntriesString());
 
 		//check if this run type exists, and check it's name is not AllRunsName
-		bool runTypeExists = Sqlite.Exists (Constants.RunTypeTable, Util.RemoveTildeAndColonAndDot(entry_name.Text));
+		bool runTypeExists = Sqlite.Exists (false, Constants.RunTypeTable, Util.RemoveTildeAndColonAndDot(entry_name.Text));
 		if(Util.RemoveTildeAndColonAndDot(entry_name.Text) == Constants.AllRunsName) {
 			runTypeExists = true;
 		}
