@@ -131,7 +131,17 @@ public class SplashWindow
 			
 
 	public void Destroy () {
-		SplashWindowBox.splash_window.Destroy ();
+		//it seem on some machines (MacOSX) splash_window maybe is Destroyed previously because on_delete_event it's called
+		//Destroy here if it has not been destroyed
+		if(SplashWindowBox.splash_window == null)
+			Log.WriteLine("splash_window is null. Do nothing.");
+		else {
+			Log.WriteLine("splash_window is not null. Destroying now...");
+			
+			SplashWindowBox.splash_window.Destroy ();
+			
+			Log.WriteLine("Destroyed!");
+		}
 	}
 
 	private void on_delete_event (object o, DeleteEventArgs args) {
