@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -49,12 +49,12 @@ class SqliteEncoder : Sqlite
 			"extraWeight TEXT, " +	//string because can contain "33%" or "50Kg"
 			"signalOrCurve TEXT, " + //"signal" or "curve"
 			"filename TEXT, " +
-			"url TEXT, " +
+			"url TEXT, " +		//URL of data of signals and curves. stored as relative
 			"time INT, " +
 			"minHeight INT, " +
 			"description TEXT, " +
 			"status TEXT, " +	//"active", "inactive"
-			"videoURL TEXT, " +	//URL of video of signals
+			"videoURL TEXT, " +	//URL of video of signals. stored as relative
 			"encoderConfiguration TEXT, " +	//text separated by ':'
 		       	"future1 TEXT, " +	//Since 1.4.4 (DB 1.06) this stores last meanPower detected on a curve 
 						//(as string with '.' because future1 was created as TEXT)
@@ -70,7 +70,7 @@ class SqliteEncoder : Sqlite
 	public static int Insert(bool dbconOpened, EncoderSQL es)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		if(es.uniqueID == "-1")
 			es.uniqueID = "NULL";
@@ -84,8 +84,10 @@ class SqliteEncoder : Sqlite
 			es.exerciseID + ", '" + es.eccon + "', '" +
 			es.laterality + "', '" + es.extraWeight + "', '" +
 			es.signalOrCurve + "', '" + es.filename + "', '" +
-			es.url + "', " + es.time + ", " + es.minHeight + ", '" + es.description + 
-			"', '" + es.status + "', '" + es.videoURL + "', '" + 
+			removeURLpath(es.url) + "', " + 
+			es.time + ", " + es.minHeight + ", '" + es.description + 
+			"', '" + es.status + "', '" + 
+			removeURLpath(es.videoURL) + "', '" + 
 			es.encoderConfiguration.ToString(":",true) + "', '" + 
 			Util.ConvertToPoint(es.future1) + "', '" + es.future2 + "', '" + es.future3 + "')";
 		Log.WriteLine(dbcmd.CommandText.ToString());
@@ -98,20 +100,30 @@ class SqliteEncoder : Sqlite
 		int myLast = Convert.ToInt32(dbcmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
 
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return myLast;
 	}
-	
+
+	//normal Update call dbcmd will be used	
 	public static void Update(bool dbconOpened, EncoderSQL es)
+	{
+		update(dbconOpened, es, dbcmd);
+	}
+	//Transaction Update call dbcmdTr will be used	
+	public static void Update(bool dbconOpened, EncoderSQL es, SqliteCommand dbcmdTr) 
+	{
+		update(dbconOpened, es, dbcmdTr);
+	}
+	private static void update(bool dbconOpened, EncoderSQL es, SqliteCommand mycmd)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		if(es.uniqueID == "-1")
 			es.uniqueID = "NULL";
 
-		dbcmd.CommandText = "UPDATE " + Constants.EncoderTable + " SET " +
+		mycmd.CommandText = "UPDATE " + Constants.EncoderTable + " SET " +
 				" personID = " + es.personID +
 				", sessionID = " + es.sessionID +
 				", exerciseID = " + es.exerciseID +
@@ -120,7 +132,7 @@ class SqliteEncoder : Sqlite
 				"', extraWeight = '" + es.extraWeight +
 				"', signalOrCurve = '" + es.signalOrCurve +
 				"', filename = '" + es.filename +
-				"', url = '" + es.url +
+				"', url = '" + removeURLpath(es.url) +
 				"', time = " + es.time +
 				", minHeight = " + es.minHeight +
 				", description = '" + es.description + 
@@ -132,32 +144,68 @@ class SqliteEncoder : Sqlite
 				"', future3 = '" + es.future3 + 
 				"' WHERE uniqueID == " + es.uniqueID ;
 
-		Log.WriteLine(dbcmd.CommandText.ToString());
-		dbcmd.ExecuteNonQuery();
+		Log.WriteLine(mycmd.CommandText.ToString());
+		mycmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
+	}
+	
+	public static int UpdateTransaction(ArrayList data, string [] checkboxes)
+	{
+		int count = 0;
+		int countActive = 0;
+
+		Log.WriteLine("Starting transaction");
+		Sqlite.Open();
+		
+		using(SqliteTransaction tr = dbcon.BeginTransaction())
+		{
+			using (SqliteCommand dbcmdTr = dbcon.CreateCommand())
+			{
+				dbcmdTr.Transaction = tr;
+	
+				foreach(EncoderSQL eSQL in data) {
+					if(eSQL.status != checkboxes[count]) {
+						eSQL.status = checkboxes[count];
+
+						SqliteEncoder.Update(true, eSQL, dbcmdTr);
+					}
+
+					count ++;
+
+					if(eSQL.status == "active") 
+						countActive ++;
+				}
+			}
+			tr.Commit();
+		}
+
+		Sqlite.Close();
+		Log.WriteLine("Ended transaction");
+		return countActive;
 	}
 	
 	//pass uniqueID value and then will return one record. do like this:
-	//EncoderSQL eSQL = (EncoderSQL) SqliteEncoder.Select(false, myUniqueID, 0, 0, "", EncoderSQL.Eccons.ALL, false, true)[0];
-	//don't care for the 0, 0 , because selection will be based on the myUniqueID and only one row will be returned
+	//EncoderSQL eSQL = (EncoderSQL) SqliteEncoder.Select(false, myUniqueID, 0, 0, 0, "", EncoderSQL.Eccons.ALL, false, true)[0];
+	//don't care for the 0, 0, 0  because selection will be based on the myUniqueID and only one row will be returned
 	//or
 	//pass uniqueID==-1 and personID, sessionID, signalOrCurve values, and will return some records
 	//personID can be -1 to get all on that session
 	//sessionID can be -1 to get all sessions
+	//exerciseID can be -1 to get all exercises
 	//signalOrCurve can be "all"
 	
 	//orderIDascendent is good for all the situations except when we want to convert from 1.05 to 1.06
 	//in that conversion, we want first the last ones, and later the previous
 	//	(to delete them if they are old copies)
 	public static ArrayList Select (
-			bool dbconOpened, int uniqueID, int personID, int sessionID, 
-			string signalOrCurve, EncoderSQL.Eccons ecconSelect,	
+			bool dbconOpened, int uniqueID, int personID, int sessionID, int exerciseID,
+			string signalOrCurve, EncoderSQL.Eccons ecconSelect,
 			bool onlyActive, bool orderIDascendent)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		string personIDStr = "";
 		if(personID != -1)
@@ -167,14 +215,18 @@ class SqliteEncoder : Sqlite
 		if(sessionID != -1)
 			sessionIDStr = " sessionID = " + sessionID + " AND ";
 
+		string exerciseIDStr = "";
+		if(exerciseID != -1)
+			exerciseIDStr = " exerciseID = " + exerciseID + " AND ";
+
 		string selectStr = "";
 		if(uniqueID != -1)
 			selectStr = Constants.EncoderTable + ".uniqueID = " + uniqueID;
 		else {
 			if(signalOrCurve == "all")
-				selectStr = personIDStr + sessionIDStr;
+				selectStr = personIDStr + sessionIDStr + exerciseIDStr;
 			else
-				selectStr = personIDStr + sessionIDStr + " signalOrCurve = '" + signalOrCurve + "'";
+				selectStr = personIDStr + sessionIDStr + exerciseIDStr + " signalOrCurve = '" + signalOrCurve + "'";
 		
 			if(ecconSelect != EncoderSQL.Eccons.ALL)
 				selectStr += " AND " + Constants.EncoderTable + ".eccon = '" + EncoderSQL.Eccons.ecS.ToString() + "'";
@@ -218,6 +270,12 @@ class SqliteEncoder : Sqlite
 				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
 			econf.FromSQL(strFull);
 			
+			//if there's no video, will be "".
+			//if there's video, will be with full path
+			string videoURL = "";
+			if(reader[14].ToString() != "")
+				videoURL = addURLpath(fixOSpath(reader[14].ToString()));
+			
 			//Log.WriteLine(econf.ToString(":", true));
 			es = new EncoderSQL (
 					reader[0].ToString(),			//uniqueID
@@ -229,12 +287,12 @@ class SqliteEncoder : Sqlite
 					reader[6].ToString(),			//extraWeight
 					reader[7].ToString(),			//signalOrCurve
 					reader[8].ToString(),			//filename
-					reader[9].ToString(),			//url
+					addURLpath(fixOSpath(reader[9].ToString())),	//url
 					Convert.ToInt32(reader[10].ToString()),	//time
 					Convert.ToInt32(reader[11].ToString()),	//minHeight
 					reader[12].ToString(),			//description
 					reader[13].ToString(),			//status
-					reader[14].ToString(),			//videoURL
+					videoURL,				//videoURL
 					econf,					//encoderConfiguration
 					Util.ChangeDecimalSeparator(reader[16].ToString()),	//future1 (meanPower on curves)
 					reader[17].ToString(),			//future2
@@ -245,7 +303,7 @@ class SqliteEncoder : Sqlite
 		}
 		reader.Close();
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return array;
 	}
@@ -254,7 +312,7 @@ class SqliteEncoder : Sqlite
 	public static ArrayList SelectCompareIntersession (bool dbconOpened, int personID)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		/* OLD, returns a row for active and a row for inactive at each session	
 		dbcmd.CommandText = 
@@ -306,7 +364,7 @@ class SqliteEncoder : Sqlite
 		}
 		reader.Close();
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return array;
 	}
@@ -330,7 +388,7 @@ class SqliteEncoder : Sqlite
 	public static void SignalCurveInsert(bool dbconOpened, int signalID, int curveID, int msCentral)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderSignalCurveTable +  
 			" (uniqueID, signalID, curveID, msCentral, future1) " + 
@@ -339,7 +397,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.ExecuteNonQuery();
 		
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 	}
 	
 
@@ -349,7 +407,7 @@ class SqliteEncoder : Sqlite
 	public static ArrayList SelectSignalCurve (bool dbconOpened, int signalID, int curveID, double msStart, double msEnd)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		string whereStr = "";
 		if(signalID != -1 || curveID != -1 || msStart != -1)
@@ -395,7 +453,7 @@ class SqliteEncoder : Sqlite
 		}
 		reader.Close();
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return array;
 	}
@@ -403,7 +461,7 @@ class SqliteEncoder : Sqlite
 	public static void DeleteSignalCurveWithCurveID(bool dbconOpened, int curveID)
 	{
 		if( ! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		dbcmd.CommandText = "Delete FROM " + Constants.EncoderSignalCurveTable +
 			" WHERE curveID == " + curveID.ToString();
@@ -411,10 +469,35 @@ class SqliteEncoder : Sqlite
 		dbcmd.ExecuteNonQuery();
 		
 		if( ! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
+	}
+	
+	//when select from database, ensure path separators are ok for this platform
+	//useful if person moved database between diff OS
+	private static string fixOSpath(string url) {
+		if(UtilAll.IsWindows())
+			return url.Replace("/","\\");
+		else
+			return url.Replace("\\","/");
+	}
+	//url and videoURL stored path is relative to be able to move data between computers
+	//then SELECT: makes it abolute (addURLpath)
+	//INSERT and UPDATE: makes it relative (removeURLpath)
+	private static string addURLpath(string url) {
+		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
+		if( ! url.StartsWith(parentDir) )
+			url = parentDir + url; 
+
+		return url;
+	}
+	private static string removeURLpath(string url) {
+		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
+		if( url.StartsWith(parentDir) )
+			url = url.Replace(parentDir, ""); 
+
+		return url;
 	}
 
-	
 
 	/*
 	 * EncoderExercise stuff
@@ -441,7 +524,7 @@ class SqliteEncoder : Sqlite
 			string ressistance, string description, string speed1RM)	 //speed1RM decimal point = '.'
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderExerciseTable +  
 				" (uniqueID, name, percentBodyWeight, ressistance, description, future1, future2, future3)" +
@@ -451,7 +534,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 	}
 
 	//Note: if this names change, or there are new, change them on both:
@@ -501,24 +584,25 @@ class SqliteEncoder : Sqlite
 		}
 	}
 
-	public static void UpdateExercise(bool dbconOpened, string name, int percentBodyWeight, 
+	public static void UpdateExercise(bool dbconOpened, string nameOld, string name, int percentBodyWeight, 
 			string ressistance, string description, string speed1RM)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		dbcmd.CommandText = "UPDATE " + Constants.EncoderExerciseTable + " SET " +
-				" percentBodyWeight = " + percentBodyWeight +
+				" name = '" + name +
+				"', percentBodyWeight = " + percentBodyWeight +
 				", ressistance = '" + ressistance +
 				"', description = '" + description +
 				"', future1 = '" + speed1RM +
-				"' WHERE name = '" + name + "'" ;
+				"' WHERE name = '" + nameOld + "'" ;
 
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 	}
 	
 	//if uniqueID != -1, returns an especific EncoderExercise that can be read like this	
@@ -526,7 +610,7 @@ class SqliteEncoder : Sqlite
 	public static ArrayList SelectEncoderExercises(bool dbconOpened, int uniqueID, bool onlyNames) 
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		string uniqueIDStr = "";
 		if(uniqueID != -1)
@@ -571,7 +655,48 @@ class SqliteEncoder : Sqlite
 
 		reader.Close();
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
+
+		return array;
+	}
+
+
+	public static ArrayList SelectEncoderRowsOfAnExercise(bool dbconOpened, int exerciseID) 
+	{
+		if(! dbconOpened)
+			Sqlite.Open();
+
+		dbcmd.CommandText = "select count(*), " + 
+			Constants.PersonTable + ".name, " +
+			Constants.SessionTable + ".name, " + 
+			Constants.SessionTable + ".date " + 
+			" FROM " + Constants.EncoderTable + ", " + Constants.PersonTable + ", " + Constants.SessionTable +
+			" WHERE exerciseID == " + exerciseID + 
+			" AND " + Constants.PersonTable + ".uniqueID == " + Constants.EncoderTable + ".personID " +
+		        " AND " + Constants.SessionTable + ".uniqueID == " + Constants.EncoderTable + ".sessionID " + 
+			" GROUP BY sessionID, personID";
+			
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		ArrayList array = new ArrayList();
+		int count = 0;
+		while(reader.Read()) {
+			array.Add(new string [] {
+					count.ToString(),
+					reader[0].ToString(), //count
+					reader[1].ToString(), //person name
+					reader[2].ToString(), //session name
+					reader[3].ToString()  //session date
+			});
+			count ++;
+		}
+
+		reader.Close();
+		if(! dbconOpened)
+			Sqlite.Close();
 
 		return array;
 	}
@@ -616,7 +741,7 @@ class SqliteEncoder : Sqlite
 	public static void Insert1RM(bool dbconOpened, int personID, int sessionID, int exerciseID, double load1RM)	
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		dbcmd.CommandText = "INSERT INTO " + Constants.Encoder1RMTable +  
 				" (uniqueID, personID, sessionID, exerciseID, load1RM, future1, future2, future3)" +
@@ -626,13 +751,13 @@ class SqliteEncoder : Sqlite
 		dbcmd.ExecuteNonQuery();
 
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 	}
 	
 	public static ArrayList Select1RM (bool dbconOpened, int personID, int sessionID, int exerciseID, bool returnPersonNameAndExerciseName)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		string whereStr = "";
 		if(personID != -1 || sessionID != -1 || exerciseID != -1) {
@@ -702,7 +827,7 @@ class SqliteEncoder : Sqlite
 		}
 		reader.Close();
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return array;
 	}
