@@ -55,7 +55,8 @@ class SqliteJumpType : Sqlite
 			"SJl:1:1:SJ jump with weight", 
 			"CMJ:1:0:CMJ jump", 
 			"CMJl:1:1:CMJ jump with weight", 
-			"slCMJ:1:0:Single-leg CMJ jump",
+			"slCMJleft:1:0:Single-leg CMJ jump",
+			"slCMJright:1:0:Single-leg CMJ jump",
 			"ABK:1:0:ABK jump", 
 			"ABKl:1:1:ABK jump with weight", 
 			"Max:1:0:;Maximum jump", 
@@ -153,7 +154,7 @@ class SqliteJumpType : Sqlite
 	{
 		string [] myStr = myJump.Split(new char[] {':'});
 		if(! dbconOpened) {
-			dbcon.Open();
+			Sqlite.Open();
 		}
 		dbcmd.CommandText = "INSERT INTO " + Constants.JumpTypeTable +  
 				" (uniqueID, name, startIn, weight, description)" +
@@ -163,7 +164,7 @@ class SqliteJumpType : Sqlite
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		if(! dbconOpened) {
-			dbcon.Close();
+			Sqlite.Close();
 		}
 	}
 
@@ -171,7 +172,7 @@ class SqliteJumpType : Sqlite
 	{
 		string [] myStr = myJump.Split(new char[] {':'});
 		if(! dbconOpened) {
-			dbcon.Open();
+			Sqlite.Open();
 		}
 		dbcmd.CommandText = "INSERT INTO " + Constants.JumpRjTypeTable + 
 				" (uniqueID, name, startIn, weight, jumpsLimited, fixedValue, description)" +
@@ -182,11 +183,11 @@ class SqliteJumpType : Sqlite
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		if(! dbconOpened) {
-			dbcon.Close();
+			Sqlite.Close();
 		}
 	}
 
-	public static string[] SelectJumpTypes(string allJumpsName, string filter, bool onlyName) 
+	public static string[] SelectJumpTypes(bool dbconOpened, string allJumpsName, string filter, bool onlyName) 
 	{
 		//allJumpsName: add and "allJumpsName" value
 		//filter: 
@@ -199,8 +200,10 @@ class SqliteJumpType : Sqlite
 		string whereString = "";
 		if(filter == "TC") { whereString = " WHERE startIn == 0 "; }
 		else if(filter == "nonTC") { whereString = " WHERE startIn == 1 "; }
-		
-		dbcon.Open();
+	
+		if(! dbconOpened)	
+			Sqlite.Open();
+
 		dbcmd.CommandText = "SELECT * " +
 			" FROM " + Constants.JumpTypeTable + " " +
 			whereString +
@@ -231,7 +234,9 @@ class SqliteJumpType : Sqlite
 		}
 
 		reader.Close();
-		dbcon.Close();
+
+		if(! dbconOpened)	
+			Sqlite.Close();
 
 		int numRows;
 		if(allJumpsName != "") {
@@ -255,7 +260,7 @@ class SqliteJumpType : Sqlite
 
 	public static string[] SelectJumpRjTypes(string allJumpsName, bool onlyName) 
 	{
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT * " +
 			" FROM " + Constants.JumpRjTypeTable + " " +
 			" ORDER BY uniqueID";
@@ -287,7 +292,7 @@ class SqliteJumpType : Sqlite
 		}
 
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 
 		int numRows;
 		if(allJumpsName != "") {
@@ -310,7 +315,7 @@ class SqliteJumpType : Sqlite
 	public static JumpType SelectAndReturnJumpType(string typeName, bool dbconOpened) 
 	{
 		if(!dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 		dbcmd.CommandText = "SELECT * " +
 			" FROM " + Constants.JumpTypeTable + " " +
 			" WHERE name  = '" + typeName +
@@ -334,7 +339,7 @@ class SqliteJumpType : Sqlite
 
 		reader.Close();
 		if(!dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return myJumpType;
 	}
@@ -342,7 +347,7 @@ class SqliteJumpType : Sqlite
 	public static JumpType SelectAndReturnJumpRjType(string typeName, bool dbconOpened) 
 	{
 		if(!dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 		dbcmd.CommandText = "SELECT * " +
 			" FROM " + Constants.JumpRjTypeTable + " " +
 			" WHERE name  = '" + typeName +
@@ -377,7 +382,7 @@ class SqliteJumpType : Sqlite
 
 		reader.Close();
 		if(!dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return myJumpType;
 	}
@@ -385,7 +390,7 @@ class SqliteJumpType : Sqlite
 	//tableName is jumpType or jumpRjType
 	public static bool HasWeight(string tableName, string typeName) 
 	{
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT weight " +
 			" FROM " + tableName +
 			" WHERE name == '" + typeName + "'";
@@ -406,14 +411,14 @@ class SqliteJumpType : Sqlite
 			}
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return hasWeight;
 	}
 
 	//we know if it has fall if it starts in 
 	public static bool HasFall(string tableName, string typeName) 
 	{
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT startIn " +
 			" FROM " + tableName +
 			" WHERE name == '" + typeName + "'";
@@ -431,41 +436,41 @@ class SqliteJumpType : Sqlite
 			}
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return hasFall;
 	}
 
 	//updates name	
 	public static void Update(string nameOld, string nameNew)
 	{
-		//dbcon.Open();
+		//Sqlite.Open();
 		dbcmd.CommandText = "UPDATE jumpType SET name = '" + nameNew + 
 			"' WHERE name == '" + nameOld + "'";
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
-		//dbcon.Close();
+		//Sqlite.Close();
 	}
 
 	public static void UpdateOther(string column, string typeName, string newValue)
 	{
-		//dbcon.Open();
+		//Sqlite.Open();
 		dbcmd.CommandText = "UPDATE jumpType SET " + column + " = '" + newValue + 
 			"' WHERE name == '" + typeName + "'";
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
-		//dbcon.Close();
+		//Sqlite.Close();
 	}
 	
 	public static void Delete(string tableName, string name, bool dbconOpened)
 	{
 		if(!dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 		dbcmd.CommandText = "Delete FROM " + tableName + 
 			" WHERE name == '" + name + "'";
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		if(!dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 	}
 
 }	
