@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2013   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -29,6 +29,61 @@ using Mono.Data.Sqlite;
 class SqliteOldConvert : Sqlite
 {
 
+	//to be easier to move data between computers, absolute paths have to be converted to relative
+	//DB 1.11 -> 1.12
+	//dbcon is already opened
+	public static void ConvertAbsolutePathsToRelative () 
+	{
+		//get parentDir with the final '/' or '\'
+		string parentDir = Util.GetParentDir(true);
+
+		ConvertAbsolutePathsToRelativeDo(parentDir, "encoder", "videoURL");
+		ConvertAbsolutePathsToRelativeDo(parentDir, "encoder", "url");
+
+		//URLs of videos of contact tests: jump, run,... are not in the database
+		//URLs of images of person77			 are not in the database
+	}
+	public static void ConvertAbsolutePathsToRelativeDo (string parentDir, string table, string column) {
+		//eg. dbcmd.CommandText = "UPDATE encoder SET videoURL = replace( videoURL, '/home/user/.local/share/Chronojump/', '' ) " + 
+		//	"WHERE videoURL LIKE '/home/user/.local/share/Chronojump/%'";
+
+		dbcmd.CommandText = "UPDATE " + table + " SET " + column + " = replace( " + column + ", '" + parentDir + "', '' ) " + 
+			"WHERE " + column + " LIKE '" + parentDir + "%'";
+
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+	}	
+
+	//convert slCMJ to slCMJleft, slCMJright
+	//DB 1.13 -> DB 1.14
+	public static void slCMJDivide() {
+		//it's a conversion, dbcon is opened
+
+		//changes on jumpType table
+		SqliteJumpType.Delete(Constants.JumpTypeTable, "slCMJ", true);
+		SqliteJumpType.JumpTypeInsert("slCMJleft:1:0:Single-leg CMJ jump", true);
+		SqliteJumpType.JumpTypeInsert("slCMJright:1:0:Single-leg CMJ jump", true);
+
+
+		//changes on jump table
+		dbcmd.CommandText = "UPDATE " + Constants.JumpTable + " SET type = 'slCMJleft' WHERE description LIKE '%Left%'";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		dbcmd.CommandText = "UPDATE " + Constants.JumpTable + " SET type = 'slCMJright' WHERE description LIKE '%Right%'";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		dbcmd.CommandText = "UPDATE " + Constants.JumpTable + " SET description=replace(description, ' Left', '')";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		dbcmd.CommandText = "UPDATE " + Constants.JumpTable + " SET description=replace(description, ' Right', '')";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+	}
+
 	//pass uniqueID value and then will return one record. do like this:
 	//EncoderSQL eSQL = (EncoderSQL) SqliteEncoder.Select(false, myUniqueID, 0, 0, "")[0];
 	//or
@@ -40,7 +95,7 @@ class SqliteOldConvert : Sqlite
 			int uniqueID, int personID, int sessionID, string signalOrCurve, bool onlyActive)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		string personIDStr = "";
 		if(personID != -1)
@@ -115,7 +170,7 @@ class SqliteOldConvert : Sqlite
 		}
 		reader.Close();
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return array;
 	}
@@ -187,7 +242,7 @@ class SqliteOldConvert : Sqlite
 			int uniqueID, int personID, int sessionID, string signalOrCurve, bool onlyActive)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		string personIDStr = "";
 		if(personID != -1)
@@ -257,7 +312,7 @@ class SqliteOldConvert : Sqlite
 		}
 		reader.Close();
 		if(! dbconOpened)
-			dbcon.Close();
+			Sqlite.Close();
 
 		return array;
 	}
