@@ -44,6 +44,14 @@ public class Util
 		myStringBuilder.Replace(",", ".");
 		return myStringBuilder.ToString();
 	}
+	
+	public static string ConvertToComma (string myString)
+	{
+		StringBuilder myStringBuilder = new StringBuilder(myString);
+		myStringBuilder.Replace(".", ",");
+		return myStringBuilder.ToString();
+	}
+
 
 	//when we do a query to the server, it returns avg as "0,54" because it's latin localized
 	//if client is on english machine, need to convert this to "0.54"
@@ -708,10 +716,16 @@ public class Util
 	/********** start of LocalApplicationData path ************/
 	
 	//parent of database, multimedia and encoder
-	public static string GetParentDir() {
-		return Path.Combine(
+	//if withFinalSeparator, then return a '\' or '/' at the end
+	public static string GetParentDir(bool withFinalSeparator) {
+		string path = Path.Combine(
 				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
 				"Chronojump");
+
+		if(withFinalSeparator)
+			path += Path.DirectorySeparatorChar;
+
+		return path;
 	}
 	
 	/********** end of LocalApplicationData path ************/
@@ -801,6 +815,7 @@ public class Util
 		}
 	}
 
+	//returns absolute path, but in encoder this URL is stored in database as relative to be able to move data between computers
 	public static string GetVideoFileName (int sessionID, Constants.TestTypes testType, int uniqueID) {
 		return GetVideoSessionDir(sessionID) + Path.DirectorySeparatorChar + 
 			testType.ToString() + "-" + uniqueID.ToString() +
@@ -873,7 +888,7 @@ public class Util
 
 	public static string GetPrefixDir(){
 		string baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory, "..");
-		if (!Directory.Exists(Path.Combine (baseDirectory, "lib", "chronojump"))) {
+		if (! Directory.Exists(Path.Combine(baseDirectory, "lib" + Path.DirectorySeparatorChar + "chronojump"))) {
 			baseDirectory = System.IO.Path.Combine(baseDirectory, "..");
 		}
 		return baseDirectory;
